<?php


namespace app\shequ\controller;


use app\admin\controller\Common;
use think\facade\Db;
use think\facade\Request;

class UserBind extends Base
{
    protected $middleware = ['app\middleware\CommunityLoginCheck::class','app\middleware\CommunityAfter::class'];

    //用户解绑房间
    public function unbind() {
        $where['house_user_bind_id'] = Request::param('bind_id');
        $status=  Request::param('status',3);
        if($status == 1) {
            $save['pass_time'] = time();
        }
        if($status == 3) {
            $save['unbind_time'] = time();
        }
        $save['status'] = $status;
        $change = Db::name('house_user_bind')->where($where)->update($save);
        if($change) {
            return $this->returnJson([],'success',200);
        } else {
            return $this->returnJson([],'error',200);
        }
    }


    //业主列表| 租客列表 | 家属列表
    public function houseOwnerList(){

        $vacancy = new Vacancy($this->app);
        $page = Request::param('page',1);
        $where[] = ['hub.type','=',Request::param('type',0)];
        if(Request::param('phone')) {
            $where[] = ['hub.phone','=',Request::param('phone')];
        }
        if(Request::param('status')) {
            $where[] = ['hub.status','=',Request::param('status')];
        }

        $total = DB::name('house_user_bind')->alias('hub')->where($where)->count();
        $data = DB::name('house_user_bind')->alias('hub')
                ->leftJoin('house_vacancy hv','hv.vacancy_id = hub.vacancy_id')
                ->where($where)
                ->order(['hub.pass_time'=>'desc','hub.status'=>'desc'])
                ->page($page,config('app.limit'))
                ->field('hub.house_user_bind_id,hub.name,hub.phone,hub.id_card,hub.pass_time,hub.unbind_time,hv.vacancy_code,hv.layout_id')
                ->select()->toArray();
        foreach ($data as $k => $v) {
            $data[$k]['vacancy_address'] = $vacancy->getVacancyAddress($v['vacancy_code'],$v['layout_id']);
        }
        $res['total'] = $total;
        $res['data'] = Common::changeField($data,['pass_time','unbind_time']);
        return $this->returnJson($res,'success');

    }


    //修改入住人员信息
    public  function changeHouseOwner() {
        $where['house_user_bind_id'] = Request::param('bind_id');
        $save['name'] = Request::param('name');
        $save['phone'] = Request::param('phone');
        $is_card = Request::param('id_card');
        if(!isCreditNo($is_card)) {
            return $this->returnJson([],'身份证号码不正确!',400);
        }
        $save['id_card'] = $is_card;
        $save['type'] = Request::param('type');
        $save['relatives_type'] = Request::param('relatives_type');
        $save['memo'] = Request::param('memo');
        $change = Db::name('house_user_bind')->where($where)->update($save);
        if($change) {
            return $this->returnJson([],'success');
        } else {
            return $this->returnJson([],'error',400);
        }
    }

    //删除绑定人员,需要用户先解绑
    public function deleteHouseOwner() {
        $where['house_user_bind_id'] = Request::param('bind_id');
        $where['village_id'] = $this->village_id;
        $bindInfo = Db::name('house_user_bind')->where($where)->field('house_user_bind_id,status')->find();
        if($bindInfo['status'] != 3) {
            return $this->returnJson([],'请先解绑用户!',400);
        }
        $del =  Db::name('house_user_bind')->where($where)->delete();
        if($del) {
            return $this->returnJson([],'success');
        } else {
            return $this->returnJson([],'error',400);
        }

    }

    //绑定人员详情
    public function detailHouseOwner() {
        $vacancy = new Vacancy($this->app);
        $where['house_user_bind_id'] = Request::param('bind_id');

        $data = Db::name('house_user_bind')->alias('ub')->leftJoin('house_vacancy hv','hv.vacancy_id = ub.vacancy_id')->where($where)
                ->field('ub.*,hv.vacancy_code,hv.layout_id')
                ->find();
        $data = Common::changeField($data);
        if($data) {
            $data['vacancy_address'] = $vacancy->getVacancyAddress($data['vacancy_code'],$data['layout_id']);
        } else {
            $data = [];
        }
        return $this->returnJson($data,'success');

    }


    //添加绑定的人员
    public function createBindUser() {
        $data['village_id'] = $this->village_id;
        $data['name'] = Request::param('name');
        $data['phone'] = Request::param('phone');
        $data['create_time'] = $data['pass_time']= time();
        $data['memo'] = Request::param('memo');
        $data['type'] = Request::param('type');
        $data['relatives_type'] = Request::param('relatives_type');
        $data['status'] = Request::param('status',1);
        $data['id_card'] = Request::param('id_card');
        //根据房间编号获取房间id,
        $vacancy_code = Request::param('vacancy_code');
        $vacancy_id = DB::name('house_vacancy')->where(['village_id'=>$this->village_id,'vacancy_code'=>$vacancy_code])->value('vacancy_id');
        if(!$vacancy_id) {
            return $this->returnJson([],'房间编号不存在!',400);
        }
        $data['vacancy_id'] = $vacancy_id;
        //查看该用户是否绑定了同一个房间的多个身份
        $is_exit = Db::name('house_user_bind')->where(['vacancy_id'=>$vacancy_id,'id_card'=>$data['id_card']])->find();
        if($is_exit) {
            return $this->returnJson([],'该身份证用户在该房间下以绑定,请勿重复绑定!',400);
        }
        //业主只能有一个
        $is_owner = Db::name('house_user_bind')->where(['village_id'=>$this->village_id,'vacancy_id'=>$vacancy_id,'type'=>0,'status'=>1])->find();
        if($is_owner) {
            return $this->returnJson([],'该房间编号下以绑定业主,请先解绑!',400);
        }
        $add = Db::name('house_user_bind')->save($data);
        if($add) {
            return $this->returnJson([],'success');
        } else {
            return $this->returnJson([],'添加失败',400);
        }

    }










}